---
name: Bug report
about: Create a report to help us improve
title: ""
labels: "kind/bug"
assignees: ""
---

**Describe the bug**
A clear and concise description of what the bug is.

Label the issue properly.

- Add `severity/` label.
- Add `documentation` label if this issue is related to documentation changes.

**To Reproduce**
Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment and Versions (please complete the following information):**
A clear and precise description of your setup:

- version for this project in use.
- services, libraries, languages and tools list and versions.

**Additional context**
Add any other context about the problem here.
